@@ -1,8 +1,6 @@
 #!/usr/bin/env perl
 
-# PERL_FUTURE_DEBUG=1 perl eg/tester.pl
-
-use v5.36;
+# PERL_FUTURE_DEBUG=1 perl eg/math.pl
 
 use curry;
 use Future::IO::Impl::IOAsync;
@@ -22,11 +20,6 @@ my $rtfm = MIDI::RtController::Filter::Math->new(rtc => $rtc);
 $rtfm->delay(0.15);
 $rtfm->feedback(6);
 
-add_filters('stair', $rtfm->curry::stair_step, 0);
+$rtc->add_filter('stair', [qw(note_on note_off)], $rtfm->curry::stair_step);
 
 $rtc->run;
-
-sub add_filters ($name, $coderef, $types) {
-    $types ||= [qw(note_on note_off)];
-    $rtc->add_filter($name, $types, $coderef);
-}
